@@ -18,6 +18,12 @@ AccountManager::AccountManager(QObject *parent)
     QSettings settings;
     migrateSettings(settings);
     loadFromSettings(settings);
+
+    connect(this, &AccountManager::accountSelected, this, [=](AbstractAccount *account) {
+        if (account != nullptr) {
+            account->checkForFollowRequests();
+        }
+    });
 }
 
 AccountManager::~AccountManager()
@@ -125,8 +131,18 @@ void AccountManager::addAccount(AbstractAccount *account)
 void AccountManager::childIdentityChanged(AbstractAccount *account)
 {
     auto config = Config::self();
-    if (selectedAccount() == nullptr || account->identity()->account() == config->lastUsedAccount()) {
+
+    // old LastUsedAccount values used to be only username
+    const bool isOldVersion = !config->lastUsedAccount().contains(QLatin1Char('@'));
+    const bool isEmpty = config->lastUsedAccount().isEmpty();
+    const bool matchesNewFormat = account->settingsGroupName() == config->lastUsedAccount();
+    const bool matchesOldFormat = account->username() == config->lastUsedAccount();
+
+    const bool isValid = isEmpty || (isOldVersion ? matchesOldFormat : matchesNewFormat);
+
+    if (selectedAccount() == nullptr && isValid) {
         selectAccount(account, false);
+        Q_EMIT accountsReady();
     }
 
     Q_EMIT identityChanged(account);
@@ -156,6 +172,15 @@ void AccountManager::removeAccount(AbstractAccount *account)
     Q_EMIT accountsChanged();
 }
 
+void AccountManager::reloadAccounts()
+{
+    for (auto account : std::as_const(m_accounts)) {
+        account->validateToken();
+    }
+
+    Q_EMIT accountsReloaded();
+}
+
 void AccountManager::selectAccount(AbstractAccount *account, bool explicitUserAction)
 {
     if (!m_accounts.contains(account)) {
@@ -167,7 +192,7 @@ void AccountManager::selectAccount(AbstractAccount *account, bool explicitUserAc
 
     if (explicitUserAction) {
         auto config = Config::self();
-        config->setLastUsedAccount(account->identity()->account());
+        config->setLastUsedAccount(account->settingsGroupName());
         config->save();
     }
 
