@@ -3,7 +3,7 @@
 
 #include "notificationmodel.h"
 #include "abstractaccount.h"
-#include "accountmodel.h"
+#include "abstracttimelinemodel.h"
 #include "threadmodel.h"
 #include <KLocalizedString>
 #include <QUrlQuery>
@@ -149,13 +149,6 @@ int NotificationModel::rowCount(const QModelIndex &parent) const
     return m_notifications.size();
 }
 
-QHash<int, QByteArray> NotificationModel::roleNames() const
-{
-    auto roles = AbstractTimelineModel::roleNames();
-    roles.insert(NotificationActorIdentityRole, QByteArrayLiteral("notificationActorIdentity"));
-    return roles;
-}
-
 QVariant NotificationModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
@@ -168,23 +161,23 @@ QVariant NotificationModel::data(const QModelIndex &index, int role) const
     switch (role) {
     case TypeRole:
         return notification->type();
-    case WasRebloggedRole:
-        return post->m_repeat || notification->type() == Notification::Repeat;
-    case RebloggedDisplayNameRole:
-        if (post->repeatIdentity()) {
-            return post->repeatIdentity()->displayNameHtml();
+    case IsBoostedRole:
+        return post->boosted() || notification->type() == Notification::Repeat;
+    case BoostAuthorIdentityRole:
+        if (post->boostIdentity()) {
+            return QVariant::fromValue<Identity *>(post->boostIdentity().get());
         }
         if (notification->type() == Notification::Repeat) {
-            return notification->identity()->displayName();
+            return QVariant::fromValue<Identity *>(notification->identity().get());
         }
         return {};
     case NotificationActorIdentityRole:
         return QVariant::fromValue(notification->identity().get());
-    case AccountModelRole:
+    case AuthorIdentityRole:
         if (notification->type() == Notification::Follow || notification->type() == Notification::FollowRequest) {
-            return QVariant::fromValue<QAbstractListModel *>(new AccountModel(notification->identity()->id(), notification->identity()->account()));
+            return QVariant::fromValue<Identity *>(notification->identity().get());
         } else {
-            return QVariant::fromValue<QAbstractListModel *>(new AccountModel(post->authorIdentity()->id(), post->authorIdentity()->account()));
+            return QVariant::fromValue<Identity *>(post->authorIdentity().get());
         }
     default:
         return postData(post, role);
@@ -204,41 +197,47 @@ void NotificationModel::actionReply(const QModelIndex &index)
 void NotificationModel::actionFavorite(const QModelIndex &index)
 {
     int row = index.row();
-    auto p = m_notifications[row]->post();
-
-    if (!p->m_isFavorite) {
-        m_account->favorite(p);
-        p->m_isFavorite = true;
-    } else {
-        m_account->unfavorite(p);
-        p->m_isFavorite = false;
-    }
-
-    Q_EMIT dataChanged(index, index);
+    auto post = m_notifications[row]->post();
+    AbstractTimelineModel::actionFavorite(index, post);
 }
 
 void NotificationModel::actionRepeat(const QModelIndex &index)
 {
-    int row = index.row();
-    auto p = m_notifications[row]->post();
-
-    if (!p->m_isRepeated) {
-        m_account->repeat(p);
-        p->m_isRepeated = true;
-    } else {
-        m_account->unrepeat(p);
-        p->m_isRepeated = false;
-    }
-
-    Q_EMIT dataChanged(index, index);
+    const int row = index.row();
+    const auto post = m_notifications[row]->post();
+    AbstractTimelineModel::actionRepeat(index, post);
 }
 
 void NotificationModel::actionVis(const QModelIndex &index)
 {
-    int row = index.row();
-    auto p = m_notifications[row]->post();
-
-    p->m_attachments_visible ^= true;
+    const int row = index.row();
+    const auto p = m_notifications[row]->post();
 
+    p->setAttachmentsVisible(!p->attachmentsVisible());
     Q_EMIT dataChanged(index, index);
 }
+
+void NotificationModel::actionRedraft(const QModelIndex &index, bool isEdit)
+{
+    const int row = index.row();
+    const auto p = m_notifications[row]->post();
+
+    AbstractTimelineModel::actionRedraft(index, p, isEdit);
+}
+
+void NotificationModel::actionDelete(const QModelIndex &index)
+{
+    const auto p = m_notifications[index.row()]->post();
+
+    AbstractTimelineModel::actionDelete(index, p);
+
+    // TODO: this sucks
+    for (auto &notification : m_notifications) {
+        if (notification->post()->postId() == p->postId()) {
+            int row = m_notifications.indexOf(notification);
+            beginRemoveRows({}, row, row);
+            m_notifications.removeOne(notification);
+            endRemoveRows();
+        }
+    }
+}
